# arpes.plotting.interactive module

**class arpes.plotting.interactive.ImageTool(curs=None,**kwargs)\*\*

> Bases: `arpes.plotting.interactive_utils.SaveableTool`,
> [arpes.plotting.interactive\_utils.CursorTool](arpes.plotting.interactive_utils#arpes.plotting.interactive_utils.CursorTool)
> 
> **deserialize(json\_data)**
> 
> **prep\_image(image\_arr)**
> 
> **serialize()**
> 
> **tool\_handler(doc)**
> 
> **tool\_handler\_2d(doc)**
> 
> **tool\_handler\_3d(doc)**
